@@ -341,12 +341,18 @@ INVALIDPARAMETERVALUE_IMAGEDECODEERROR = 'InvalidParameterValue.ImageDecodeError
 # 参数错误：图片水印模板。
 INVALIDPARAMETERVALUE_IMAGETEMPLATE = 'InvalidParameterValue.ImageTemplate'
 
+# Index 参数错误。
+INVALIDPARAMETERVALUE_INDEX = 'InvalidParameterValue.Index'
+
 # 参数值错误：Interval 无效。
 INVALIDPARAMETERVALUE_INTERVAL = 'InvalidParameterValue.Interval'
 
 # 参数错误：无效的操作类型。
 INVALIDPARAMETERVALUE_INVALIDOPERATIONTYPE = 'InvalidParameterValue.InvalidOperationType'
 
+# 参数值错误：错误固化参数。
+INVALIDPARAMETERVALUE_ISPERSISTENCE = 'InvalidParameterValue.IsPersistence'
+
 # Isps 参数错误。
 INVALIDPARAMETERVALUE_ISPS = 'InvalidParameterValue.Isps'
 
@@ -407,12 +413,21 @@ INVALIDPARAMETERVALUE_OPERATION = 'InvalidParameterValue.Operation'
 # 参数值错误：文件原存储类型异常。
 INVALIDPARAMETERVALUE_ORIGINALSTORAGECLASS = 'InvalidParameterValue.OriginalStorageClass'
 
+# 参数值错误：错误的输出媒体文件类型。
+INVALIDPARAMETERVALUE_OUTPUTMEDIATYPE = 'InvalidParameterValue.OutputMediaType'
+
 # 参数值错误：ParentId 无效。
 INVALIDPARAMETERVALUE_PARENTID = 'InvalidParameterValue.ParentId'
 
 # 参数值错误：人脸图片格式错误。
 INVALIDPARAMETERVALUE_PICFORMATERROR = 'InvalidParameterValue.PicFormatError'
 
+# 参数值错误：错误的精度参数。
+INVALIDPARAMETERVALUE_PRECISION = 'InvalidParameterValue.Precision'
+
+# 参数值错误：错误的 Procedure 。
+INVALIDPARAMETERVALUE_PROCEDURE = 'InvalidParameterValue.Procedure'
+
 # 任务流模板名无效。
 INVALIDPARAMETERVALUE_PROCEDURENAME = 'InvalidParameterValue.ProcedureName'
 
@@ -446,6 +461,12 @@ INVALIDPARAMETERVALUE_REVIEWCONFIDENCE = 'InvalidParameterValue.ReviewConfidence
 # 参数值错误：ReviewWallSwitch 参数取值非法。
 INVALIDPARAMETERVALUE_REVIEWWALLSWITCH = 'InvalidParameterValue.ReviewWallSwitch'
 
+# RoundPlayId 参数错误。
+INVALIDPARAMETERVALUE_ROUNDPLAYID = 'InvalidParameterValue.RoundPlayId'
+
+# RoundPlaylist 参数长度错误。
+INVALIDPARAMETERVALUE_ROUNDPLAYLIST = 'InvalidParameterValue.RoundPlaylist'
+
 # 参数值错误：RowCount。
 INVALIDPARAMETERVALUE_ROWCOUNT = 'InvalidParameterValue.RowCount'
 
@@ -458,6 +479,12 @@ INVALIDPARAMETERVALUE_SAMPLERATE = 'InvalidParameterValue.SampleRate'
 # 参数值错误：SampleType。
 INVALIDPARAMETERVALUE_SAMPLETYPE = 'InvalidParameterValue.SampleType'
 
+# 参数错误：Scheme 无效。
+INVALIDPARAMETERVALUE_SCHEME = 'InvalidParameterValue.Scheme'
+
+# 域名没有开启 https。
+INVALIDPARAMETERVALUE_SCHEMECONFLICT = 'InvalidParameterValue.SchemeConflict'
+
 # 参数值错误：ScreenshotInterval 参数取值非法。
 INVALIDPARAMETERVALUE_SCREENSHOTINTERVAL = 'InvalidParameterValue.ScreenshotInterval'
 
@@ -572,6 +599,9 @@ INVALIDPARAMETERVALUE_TYPES = 'InvalidParameterValue.Types'
 # 去重识别码一天内重复，请求被去重。
 INVALIDPARAMETERVALUE_UNIQUEIDENTIFIER = 'InvalidParameterValue.UniqueIdentifier'
 
+# 域名不能被设置。
+INVALIDPARAMETERVALUE_UNSUPPORTDOMAIN = 'InvalidParameterValue.UnsupportDomain'
+
 # 参数值错误：文件不支持该解冻方式。
 INVALIDPARAMETERVALUE_UNSUPPORTEDRESTORETIER = 'InvalidParameterValue.UnsupportedRestoreTier'
 
@@ -620,6 +650,15 @@ LIMITEXCEEDED = 'LimitExceeded'
 # 超过限制值：新旧打点信息个数和超过限制值。
 LIMITEXCEEDED_KEYFRAMEDESCCOUNTREACHMAX = 'LimitExceeded.KeyFrameDescCountReachMax'
 
+# 播放列表长度太大。
+LIMITEXCEEDED_PLAYLIST = 'LimitExceeded.PlayList'
+
+# 超过播单总数限制。
+LIMITEXCEEDED_ROUNDPLAYS = 'LimitExceeded.RoundPlays'
+
+# 运行中的播单超过最大数量。
+LIMITEXCEEDED_RUNNINGROUNDPLAYS = 'LimitExceeded.RunningRoundPlays'
+
 # 超过限制值：新旧标签个数和超过限制值。
 LIMITEXCEEDED_TAGCOUNTREACHMAX = 'LimitExceeded.TagCountReachMax'
 
@@ -665,6 +704,9 @@ RESOURCEUNAVAILABLE_MASTERPLAYLIST = 'ResourceUnavailable.MasterPlaylist'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 域名解析验证失败
+UNAUTHORIZEDOPERATION_DOMAINRECORDNOTVERIFIED = 'UnauthorizedOperation.DomainRecordNotVerified'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
